@@ -1,13 +1,18 @@
 # -*- coding: utf-8 -*-
+import json
+
 from brewtils.errors import ModelValidationError
 from brewtils.models import Operation
 from brewtils.schema_parser import SchemaParser
 
 from beer_garden.api.authorization import Permissions
 from beer_garden.api.http.handlers import AuthorizationHandler
+from beer_garden.api.http.schemas.v1.garden import GardenReadSchema
+from beer_garden.authorization import user_has_permission_for_object
 from beer_garden.db.mongo.api import MongoParser
 from beer_garden.db.mongo.models import Garden
 from beer_garden.garden import local_garden
+from beer_garden.user import initiate_user_sync
 
 GARDEN_CREATE = Permissions.GARDEN_CREATE.value
 GARDEN_READ = Permissions.GARDEN_READ.value
@@ -40,7 +45,10 @@ class GardenAPI(AuthorizationHandler):
         """
         garden = self.get_or_raise(Garden, GARDEN_READ, name=garden_name)
 
-        response = MongoParser.serialize(garden)
+        if user_has_permission_for_object(self.current_user, GARDEN_UPDATE, garden):
+            response = MongoParser.serialize(garden)
+        else:
+            response = GardenReadSchema().dumps(garden).data
 
         self.set_header("Content-Type", "application/json; charset=UTF-8")
         self.write(response)
@@ -179,8 +187,15 @@ class GardenListAPI(AuthorizationHandler):
           - Garden
         """
         permitted_gardens = self.permissioned_queryset(Garden, GARDEN_READ)
+        response_gardens = []
 
-        response = MongoParser.serialize(permitted_gardens, to_string=True)
+        for garden in permitted_gardens.no_cache():
+            if user_has_permission_for_object(self.current_user, GARDEN_UPDATE, garden):
+                response_gardens.append(MongoParser.serialize(garden))
+            else:
+                response_gardens.append(GardenReadSchema().dump(garden).data)
+
+        response = json.dumps(response_gardens)
 
         self.set_header("Content-Type", "application/json; charset=UTF-8")
         self.write(response)
@@ -231,6 +246,7 @@ class GardenListAPI(AuthorizationHandler):
           updates to apply. Currently the only operations are:
 
           * sync
+          * sync_users
 
           ```JSON
           [
@@ -250,10 +266,8 @@ class GardenListAPI(AuthorizationHandler):
             schema:
               $ref: '#/definitions/Patch'
         responses:
-          200:
-            description: Execute Patch action against Gardens
-            schema:
-              $ref: '#/definitions/Garden'
+          204:
+            description: Patch operation has been successfully forwarded
           400:
             $ref: '#/definitions/400Error'
           404:
@@ -271,14 +285,18 @@ class GardenListAPI(AuthorizationHandler):
             operation = op.operation.lower()
 
             if operation == "sync":
-                response = await self.client(
+                await self.client(
                     Operation(
                         operation_type="GARDEN_SYNC",
                     )
                 )
+            elif operation == "sync_users":
+                # requires GARDEN_UPDATE for all gardens
+                for garden in Garden.objects.all():
+                    self.verify_user_permission_for_object(GARDEN_UPDATE, garden)
 
+                initiate_user_sync()
             else:
                 raise ModelValidationError(f"Unsupported operation '{op.operation}'")
 
-        self.set_header("Content-Type", "application/json; charset=UTF-8")
-        self.write(response)
+        self.set_status(204)
