@@ -79,6 +79,7 @@ __all__ = [
     "Role",
     "RoleAssignment",
     "User",
+    "RemoteUser",
     "CommandPublishingBlockList",
 ]
 
@@ -935,12 +936,22 @@ class RoleAssignmentDomain(EmbeddedDocument):
     scope = StringField(required=True, choices=["Garden", "Global", "System"])
     identifiers = DictField(required=False)
 
-    def clean(self):
+    def _ensure_identifiers_are_present(self):
         if self.identifiers == {} and self.scope != "Global":
             raise ValidationError(
                 "identifiers field is required for all scopes other than Global"
             )
 
+    def _remove_empty_identifiers(self):
+        for key in list(self.identifiers.keys()):
+            value = self.identifiers[key]
+            if value is None or value.strip() == "":
+                _ = self.identifiers.pop(key)
+
+    def clean(self):
+        self._remove_empty_identifiers()
+        self._ensure_identifiers_are_present()
+
 
 class RoleAssignment(EmbeddedDocument):
     domain = EmbeddedDocumentField(RoleAssignmentDomain, required=True)
@@ -958,6 +969,9 @@ class User(Document):
 
     _permissions_cache: Optional[dict] = None
 
+    def __str__(self) -> str:
+        return self.username
+
     @property
     def permissions(self) -> dict:
         """Return the user's permissions organized by permission name. This is
@@ -1056,3 +1070,20 @@ class UserToken(Document):
             {"fields": ["expires_at"], "expireAfterSeconds": 0},
         ]
     }
+
+
+class RemoteUser(Document):
+    username = StringField(required=True)
+    garden = StringField(required=True)
+    role_assignments = ListField(field=DictField(), required=False)
+    updated_at = DateTimeField(required=True, default=datetime.datetime.utcnow)
+
+    meta = {
+        "indexes": [
+            {"fields": ["username"]},
+            {"fields": ["garden", "username"], "unique": True},
+        ],
+    }
+
+    def __str__(self):
+        return f"{self.garden}:{self.username}"
