@@ -860,7 +860,7 @@ def process_wait(request: Request, timeout: float) -> Request:
     return db.query_unique(Request, id=created_request.id)
 
 
-def handle_event(event):
+def handle_wait_events(event):
     # Whenever a request is completed check to see if this process is waiting for it
     if event.name == Events.REQUEST_COMPLETED.name:
         completion_event = request_map.pop(event.payload.id, None)
@@ -877,8 +877,10 @@ def handle_event(event):
             for request_event in request_map:
                 request_map[request_event].set()
 
+
+def handle_event(event):
     # Only care about downstream garden
-    elif event.garden != config.get("garden.name") and not event.error:
+    if event.garden != config.get("garden.name") and not event.error:
         if event.name in (
             Events.REQUEST_CREATED.name,
             Events.REQUEST_STARTED.name,
@@ -891,17 +893,24 @@ def handle_event(event):
             # the subset of fields that change "corrects" the parent
             existing_request = db.query_unique(Request, id=event.payload.id)
 
-            if existing_request:
-                for field in ("status", "output", "error_class", "status_updated_at"):
-                    setattr(existing_request, field, getattr(event.payload, field))
-
-                try:
-                    update_request(existing_request)
-                except RequestStatusTransitionError:
-                    pass
-            else:
+            if existing_request is None:
                 # Attempt to create the request, if it already exists then continue on
                 try:
                     db.create(event.payload)
                 except NotUniqueException:
                     pass
+            elif event.name != Events.REQUEST_CREATED.name:
+                request_changed = False
+
+                for field in ("status", "output", "error_class", "status_updated_at"):
+                    new_value = getattr(event.payload, field)
+
+                    if getattr(existing_request, field) != new_value:
+                        request_changed = True
+                        setattr(existing_request, field, new_value)
+
+                if request_changed:
+                    try:
+                        update_request(existing_request, _publish_error=False)
+                    except RequestStatusTransitionError:
+                        pass
